# {pipeline_name}

## Description

This is a new pipeline created using the `pipeline-ai` CLI.

### Configuration

This pipeline uses the following `pipeline.yaml`:

{pipeline_yaml}

## Usage

_Put usage information here_

## Code

{pipeline_code}

## License

_Put license information here_

## Author

_Put author information here_

---

_This is an autogenerated README file for the pipeline `{pipeline_name}`. Please read more information about this [here on our docs](https://docs.mystic.ai/docs/using-the-readmemd)_
